/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2018 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: 5.02a                                            *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for S12ZVMEVB eval board
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define PIM_BASE_ADDR  (0x00000200u)
#define MODRR0_REG     (*(volatile unsigned char*)(PIM_BASE_ADDR + 0x00u))
#define PTS_REG        (*(volatile unsigned char*)(PIM_BASE_ADDR + 0xD0u))
#define DDRS_REG       (*(volatile unsigned char*)(PIM_BASE_ADDR + 0xD2u))
#define LED1_BIT       (4u)
#define LED2_BIT       (5u)

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  MODRR0_REG |= 0x08;
  DDRS_REG   |= 0x30;
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index == 0) {
  PTS_REG |= (1u << LED1_BIT);   // Switch on LED1
  } else if (Index == 1) {
  PTS_REG |= (1u << LED2_BIT);   // Switch on LED2
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index == 0) {
  PTS_REG &= ~(1u << LED1_BIT);  // Switch off LED1
  } else if (Index == 1) {
  PTS_REG &= ~(1u << LED2_BIT);  // Switch off LED2
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index == 0) {
  PTS_REG ^= (1u << LED1_BIT);   // Toggle LED1
  } else if (Index == 1) {
  PTS_REG ^= (1u << LED2_BIT);   // Toggle LED2
  }
}

/****** End Of File *************************************************/
