/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2018 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: 5.02a                                            *
*                                                                    *
**********************************************************************

-------------------------- END-OF-HEADER -----------------------------
File    : Vectors.c
Purpose : Vector table for MC9S12ZVML.
*/

/*********************************************************************
*
*       Declarations
*
**********************************************************************
*/

typedef void (*vecAddress)(void);   // ISR prototype
typedef struct typeVect {           // Extend ISR addr. to 32 bits using dummy chars.
  char       dummy;
  vecAddress Address;
} typeVect;

extern interrupt void SysTick_Handler     (void);  // Implemented in RTOSInit.c
       interrupt void Default_ISRHandler  (void);  // Implemented in Vectors.c
       interrupt void Exception_ISRHandler(void);  // Implemented in Vectors.c

/*********************************************************************
*
*       Static data
*
**********************************************************************
*/
static const typeVect _InterruptVectorTable[92] @0xFFFE8Cu = {
  //
  // After reset, IVBR points to 0xFFFE00.
  // Initial addresses 0xFFFE10 to 0xFFFE88 are reserved, hence we do not list them here.
  //
                           // Address    Source
  0x00,
  Default_ISRHandler,      // 0xFFFE8C   TIM1 timer overflow (ZVMC256 Only)
  0x00,
  Default_ISRHandler,      // 0xFFFE90   Reserved
  0x00,
  Default_ISRHandler,      // 0xFFFE94   Reserved
  0x00,
  Default_ISRHandler,      // 0xFFFE98   Reserved
  0x00,
  Default_ISRHandler,      // 0xFFFE9C   Reserved
  0x00,
  Default_ISRHandler,      // 0xFFFEA0   Reserved
  0x00,
  Default_ISRHandler,      // 0xFFFEA4   Reserved
  0x00,
  Default_ISRHandler,      // 0xFFFEA8   TIM1 timer channel 1 (ZVMC256 Only)
  0x00,
  Default_ISRHandler,      // 0xFFFEAC   TIM1 timer channel 0 (ZVMC256 Only)
  0x00,
  Default_ISRHandler,      // 0xFFFEB0   Reserved
  0x00,
  Default_ISRHandler,      // 0xFFFEB4   Reserved
  0x00,
  Default_ISRHandler,      // 0xFFFEB8   Reserved
  0x00,
  Default_ISRHandler,      // 0xFFFEBC   Port L interrupt (ZVMC256 Only)
  0x00,
  Default_ISRHandler,      // 0xFFFEC0   PMF Reload Overrun
  0x00,
  Default_ISRHandler,      // 0xFFFEC4   PMF Fault
  0x00,
  Default_ISRHandler,      // 0xFFFEC8   PMF Reload C
  0x00,
  Default_ISRHandler,      // 0xFFFECC   PMF Reload B
  0x00,
  Default_ISRHandler,      // 0xFFFED0   PMF Reload A
  0x00,
  Default_ISRHandler,      // 0xFFFED4   Reserved
  0x00,
  Default_ISRHandler,      // 0xFFFED8   Reserved
  0x00,
  Default_ISRHandler,      // 0xFFFEDC   Reserved
  0x00,
  Default_ISRHandler,      // 0xFFFEE0   PTU Trigger1 Done
  0x00,
  Default_ISRHandler,      // 0xFFFEE4   PTU Trigger0 Done
  0x00,
  Default_ISRHandler,      // 0xFFFEE8   PTU Trigger1 Error
  0x00,
  Default_ISRHandler,      // 0xFFFEEC   PTU Trigger0 Error
  0x00,
  Default_ISRHandler,      // 0xFFFEF0   PTU Reload Overrun
  0x00,
  Default_ISRHandler,      // 0xFFFEF4   Port AD Interrupt
  0x00,
  Default_ISRHandler,      // 0xFFFEF8   VDDS integrity interrupt
  0x00,
  Default_ISRHandler,      // 0xFFFEFC   High temperature interrupt
  0x00,
  Default_ISRHandler,      // 0xFFFF00   Autonomous periodical interrupt
  0x00,
  Default_ISRHandler,      // 0xFFFF04   Low voltage interrupt
  0x00,
  Default_ISRHandler,      // 0xFFFF08   EVDD1 over-current interrupt
  0x00,
  Default_ISRHandler,      // 0xFFFF0C   Port P interrupt
  0x00,
  Default_ISRHandler,      // 0xFFFF10   Reserved
  0x00,
  Default_ISRHandler,      // 0xFFFF14   ADC1 conversion complete
  0x00,
  Default_ISRHandler,      // 0xFFFF18   ADC1 conversion sequence abort
  0x00,
  Default_ISRHandler,      // 0xFFFF1C   ADC1 error
  0x00,
  Default_ISRHandler,      // 0xFFFF20   Reserved
  0x00,
  Default_ISRHandler,      // 0xFFFF24   Port S interrupt
  0x00,
  Default_ISRHandler,      // 0xFFFF28   CAN Physical layer
  0x00,
  Default_ISRHandler,      // 0xFFFF2C   Reserved
  0x00,
  Default_ISRHandler,      // 0xFFFF30   Reserved
  0x00,
  Default_ISRHandler,      // 0xFFFF34   Reserved
  0x00,
  Default_ISRHandler,      // 0xFFFF38   GDU Voltage Limit Detected
  0x00,
  Default_ISRHandler,      // 0xFFFF3C   GDU Desauration Error
  0x00,
  Default_ISRHandler,      // 0xFFFF40   BATS supply voltage monitor interrupt
  0x00,
  Default_ISRHandler,      // 0xFFFF44   LINPHY over-current interrupt
  0x00,
  Default_ISRHandler,      // 0xFFFF48   Reserved
  0x00,
  Default_ISRHandler,      // 0xFFFF4C   Reserved
  0x00,
  Default_ISRHandler,      // 0xFFFF50   CAN0 transmit
  0x00,
  Default_ISRHandler,      // 0xFFFF54   CAN0 receive
  0x00,
  Default_ISRHandler,      // 0xFFFF58   CAN0 errors
  0x00,
  Default_ISRHandler,      // 0xFFFF5C   CAN0 wake-up
  0x00,
  Default_ISRHandler,      // 0xFFFF60   FLASH command
  0x00,
  Default_ISRHandler,      // 0xFFFF64   FLASH error
  0x00,
  Default_ISRHandler,      // 0xFFFF68   Reserved
  0x00,
  Default_ISRHandler,      // 0xFFFF6C   Reserved
  0x00,
  Default_ISRHandler,      // 0xFFFF70   RAM Error
  0x00,
  Default_ISRHandler,      // 0xFFFF74   Reserved
  0x00,
  Default_ISRHandler,      // 0xFFFF78   Reserved
  0x00,
  Default_ISRHandler,      // 0xFFFF7C   PLL lock interrupt
  0x00,
  Default_ISRHandler,      // 0xFFFF80   Oscillator status interrupt
  0x00,
  Default_ISRHandler,      // 0xFFFF84   ADC0 conversion complete
  0x00,
  Default_ISRHandler,      // 0xFFFF88   ADC0 conversion sequence abort
  0x00,
  Default_ISRHandler,      // 0xFFFF8C   ADC0 Error
  0x00,
  Default_ISRHandler,      // 0xFFFF90   Reserved
  0x00,
  Default_ISRHandler,      // 0xFFFF94   Reserved
  0x00,
  Default_ISRHandler,      // 0xFFFF98   SCI1
  0x00,
  Default_ISRHandler,      // 0xFFFF9C   SCI0
  0x00,
  Default_ISRHandler,      // 0xFFFFA0   SPI0
  0x00,
  Default_ISRHandler,      // 0xFFFFA4   Reserved
  0x00,
  Default_ISRHandler,      // 0xFFFFA8   Reserved
  0x00,
  Default_ISRHandler,      // 0xFFFFAC   TIM0 timer overflow
  0x00,
  Default_ISRHandler,      // 0xFFFFB0   Reserved
  0x00,
  Default_ISRHandler,      // 0xFFFFB4   Reserved
  0x00,
  Default_ISRHandler,      // 0xFFFFB8   Reserved
  0x00,
  Default_ISRHandler,      // 0xFFFFBC   Reserved
  0x00,
  Default_ISRHandler,      // 0xFFFFC0   TIM0 timer channel 3
  0x00,
  Default_ISRHandler,      // 0xFFFFC4   TIM0 timer channel 2
  0x00,
  Default_ISRHandler,      // 0xFFFFC8   TIM0 timer channel 1
  0x00,
  SysTick_Handler,         // 0xFFFFCC   TIM0 timer channel 0
  0x00,
  Default_ISRHandler,      // 0xFFFFD0   RTI time-out interrupt
  0x00,
  Default_ISRHandler,      // 0xFFFFD4   IRQ interrupt request
  0x00,
  Default_ISRHandler,      // 0xFFFFD8   XIRQ interrupt request
  0x00,
  Default_ISRHandler,      // 0xFFFFDC   Spurious interrupt request
  0x00,
  Default_ISRHandler,      // 0xFFFFE0   Reserved
  0x00,
  Default_ISRHandler,      // 0xFFFFE4   Reserved
  0x00,
  Exception_ISRHandler,    // 0xFFFFE8   Machine exception vector request
  0x00,
  Default_ISRHandler,      // 0xFFFFEC   System call interrupt instruction (SYS) vector request
  0x00,
  Default_ISRHandler,      // 0xFFFFF0   Software interrupt instruction (SWI) vector request
  0x00,
  Default_ISRHandler,      // 0xFFFFF4   Unimplemented page2 op-code trap (TRAP) vector request
  0x00,
  Default_ISRHandler       // 0xFFFFF8   Unimplemented page1 op-code trap (SPARE) vector request

                           // 0xFFFFFC   Pin reset, power-on reset, low-voltage reset, clock monitor reset, COP watchdog reset
};

/*********************************************************************
*
*       Local functions
*
**********************************************************************
*/

/*********************************************************************
*
*       Default_ISRHandler()
*
*  Function description
*    Default ISR handler. Used as a dummy handler for most interrupt sources.
*/
interrupt void Default_ISRHandler(void) {
  while (1) {
    ;
  }
}

/*********************************************************************
*
*       Exception_ISRHandler()
*
*  Function description
*    Machine exception handler. May be used to detect fault exceptions.
*/
interrupt void Exception_ISRHandler(void) {
  while (1) {
    ;
  }
}

/****** End Of File *************************************************/
